@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,9 +18,17 @@
  *
  */
 
+#define VSTREAM_DOMAIN "DCMTK4MIA"
+
 #include <mia/core/errormacro.hh>
 #include <map>
 #include <algorithm>
+#include <cassert>
+#include <iomanip>
+
+#include <boost/algorithm/string/split.hpp>
+#include <boost/algorithm/string/classification.hpp>
+
 
 #include <dicom/dicom4mia.hh>
 
@@ -70,12 +78,25 @@ const SLookupInit lookup_init[] = {
 	{IDStudyID, DCM_StudyID, false, tr_no, NULL},
 	{IDImageType, DCM_ImageType, false, tr_no, NULL},
 	{IDSliceLocation, DCM_SliceLocation, false, tr_no, NULL},
+	{IDSliceThickness, DCM_SliceThickness, false, tr_no, NULL},
 	{IDPatientOrientation, DCM_PatientOrientation, false, tr_no, NULL},
 	{IDMediaStorageSOPClassUID, DCM_MediaStorageSOPClassUID, true, tr_no, NULL},
 	{IDSOPClassUID, DCM_SOPClassUID, false, tr_no, NULL},
 	{IDProtocolName, DCM_ProtocolName, false, tr_no, NULL},
 	{IDTestValue, DcmTagKey(), false, tr_no, NULL},
 	{IDPatientPosition, DCM_PatientPosition, false, tr_no, NULL}, 
+//	{IDAcquisitionTime, DCM_AcquisitionTime, false, tr_no, NULL}, 
+
+	{IDPositionerPrimaryAngle, DCM_PositionerPrimaryAngle, false, tr_no, NULL}, 
+	{IDPositionerSecondaryAngle, DCM_PositionerSecondaryAngle, false, tr_no, NULL}, 
+	{IDImagerPixelSpacing, DCM_ImagerPixelSpacing, false, tr_no, NULL},
+	{IDDistanceSourceToDetector, DCM_DistanceSourceToDetector, false, tr_no, NULL},
+	{IDDistanceSourceToPatient, DCM_DistanceSourceToPatient, false, tr_no, NULL},
+	{IDPixelIntensityRelationship, DCM_PixelIntensityRelationship, false, tr_no, NULL},
+	{IDPositionerPrimaryAngleIncrement, DCM_PositionerPrimaryAngleIncrement, false, tr_no, NULL},
+	{IDPositionerSecondaryAngleIncrement, DCM_PositionerSecondaryAngleIncrement, false, tr_no, NULL},
+	{IDPhotometricInterpretation, DCM_PhotometricInterpretation, false, tr_yes_defaulted, "MONOCHROME2"},
+	
 	{NULL, DcmTagKey(), false, tr_no, NULL}
 };
 
@@ -107,7 +128,8 @@ struct CDicomReaderData {
 	Sint32 getSint32(const DcmTagKey &tagKey, bool required, Sint32 default_value = 0);
 	float getFloat32(const DcmTagKey &tagKey, bool required, float default_value = 0);
 	float getFloat64(const DcmTagKey &tagKey, bool required, double default_value = 0);
-
+	bool getFloat64ArrayFromString(const DcmTagKey &tagKey, vector<double>& values, const string& msg);
+	
 	string getAttribute(const string& key, bool required, const char *default_value = "");
 	string getAttribute(const DcmTagKey &tagKey, bool required, const char *default_value = "");
 
@@ -119,11 +141,14 @@ struct CDicomReaderData {
 	template <typename I>
 	void getPixelData_LittleEndianExplicitTransfer(I out_begin, size_t size);
 
+	void getAcquisitionTimeIfAvailable(CAttributedData& image); 
 
 	C2DFVector getPixelSize();
 
 	C2DFVector getImagePixelSpacing(); 
-
+	
+	C3DDMatrix getImageOrientationPatient(); 
+	C3DFVector getImagePositionPatient(); 
 
 };
 
@@ -216,10 +241,18 @@ P2DImage CDicomReader::load_image()const
 
 	// get pixel data
 	impl->getPixelData(result->begin(), result->size());
+	impl->getAcquisitionTimeIfAvailable(*result); 
+	
+	auto psize = get_pixel_size(); 
+	if (psize.x < 0) {
+		psize.x = -psize.x; 
+		result->set_attribute(IDAttrPixelSizeIsImager, PAttribute(new TAttribute<int>(1)));
+	}
 
-	result->set_pixel_size(get_pixel_size());
-
-
+	result->set_pixel_size(psize);
+	result->set_attribute("rotation3d", PAttribute(new C3DRotationAttribute(this->impl->getImageOrientationPatient()))); 
+	result->set_attribute("origin3d", PAttribute(new CVoxelAttribute(this->impl->getImagePositionPatient())));
+	
 	const SLookupInit *attr_table = lookup_init;
 	while (attr_table->skey) {
 		// copy some attributes
@@ -247,8 +280,16 @@ P3DImage CDicomReader::load_image3d()const
 	// get pixel data
 	impl->getPixelData(result->begin(), result->size());
 
-	result->set_voxel_size(this->get_voxel_size(true));
 
+	auto vsize = this->get_voxel_size(true); 
+	if (vsize.x < 0) {
+		vsize.x = -vsize.x; 
+		result->set_attribute(IDAttrPixelSizeIsImager, PAttribute(new TAttribute<int>(1)));
+	}
+	result->set_voxel_size(vsize);
+
+	result->set_rotation(this->impl->getImageOrientationPatient()); 
+	result->set_origin(this->impl->getImagePositionPatient()); 
 
 	const SLookupInit *attr_table = lookup_init;
 	while (attr_table->skey) {
@@ -278,10 +319,13 @@ P2DImage CDicomReader::get_image() const
 
 
 	if (bbpa == 16) {
-		if (pixel_signed) 
+		if (pixel_signed) {
+			cvdebug() << "Load signed short\n"; 
 			return load_image<signed short>();
-		else
+		} else {
+			cvdebug() << "Load unsigned short\n"; 
 			return load_image<unsigned short>();
+		}
 	}
 
 	throw create_exception<invalid_argument>( "CDicomReader: '", m_filename, 
@@ -377,6 +421,29 @@ float CDicomReaderData::getFloat32(const DcmTagKey &tagKey, bool required, float
 	return value;
 }
 
+void CDicomReaderData::getAcquisitionTimeIfAvailable(CAttributedData& image)
+{
+	DcmElement *element; 
+	OFCondition success = dcm.getDataset()->findAndGetElement(DCM_AcquisitionTime, element); 
+	
+	if (!success.good()) 
+		return; 
+
+	DcmTime *dcm_time  = dynamic_cast<DcmTime *>(element); 
+	if (!dcm_time) {
+		cverr() << "CDicomReader: Element with tag "<<IDAcquisitionTime<< " not a DcmTime as expected\n"; 
+		return; 
+	}
+	
+	OFTime of_time; 
+	success = dcm_time->getOFTime(of_time); 
+	if (!success.good()) {
+		cverr() << "CDicomReader: Could not retrive OFTime string from DcmTime Element\n";
+		return; 
+	}
+	image.set_attribute(IDAcquisitionTime, of_time.getTimeInSeconds()); 
+}						
+
 float CDicomReaderData::getFloat64(const DcmTagKey &tagKey, bool required, double default_value)
 {
 	Float64 value = default_value;
@@ -389,6 +456,62 @@ float CDicomReaderData::getFloat64(const DcmTagKey &tagKey, bool required, doubl
 	return value;
 }
 
+bool CDicomReaderData::getFloat64ArrayFromString(const DcmTagKey &tagKey, vector<double>& values, const string& msg)
+{
+	if (!dcm.getDataset()->tagExistsWithValue(tagKey)) {
+		cvinfo() << msg << " tag empty or not available.\n"; 
+		return false; 
+	}
+	OFString help;
+	OFCondition success = dcm.getDataset()->findAndGetOFStringArray(tagKey, help);	
+	if (success.bad()) {
+		cvinfo() << msg << " available but is not a string.\n";
+		return false; 
+	}
+
+        vector<string> tockens; 
+	string svalues(help.begin(), help.end()); 
+        boost::split(tockens, svalues ,boost::is_any_of("\\"));
+
+	if (tockens.size() != values.size()) {
+		cvwarn() << "Bogus " << msg << " attribute of " << tockens.size() 
+			 << " elements (expect "<< values.size() << ")."; 
+		return false; 
+	}
+	for (unsigned i = 0; i < tockens.size(); ++i) {
+		istringstream iss(tockens[i]); 
+                iss >> values[i]; 
+                if (iss.bad()) {
+                        cvwarn() << "unable to read double value from '" << tockens[i] << "'\n"; 
+			return false;
+		}
+        }
+	return true; 
+
+}
+
+C3DDMatrix CDicomReaderData::getImageOrientationPatient()
+{
+	vector<double> v(6); 
+	
+	if (!getFloat64ArrayFromString(DCM_ImageOrientationPatient, v, "ImageOrientationPatient")) 
+		return C3DDMatrix::_1; 
+	
+	
+	const C3DDVector cx(v[0], v[1], v[2]); 
+	const C3DDVector cy(v[3], v[4], v[5]); 
+	const C3DDVector cz = cross(cx,cy); 
+	
+	return C3DDMatrix(cx, cy, cz); 
+}
+
+C3DFVector CDicomReaderData::getImagePositionPatient()
+{
+	vector<double> v(3); 
+	if (!getFloat64ArrayFromString(DCM_ImagePositionPatient, v, "ImagePositionPatient")) 
+		return C3DFVector::_0; 
+	return C3DFVector(v[0], v[1], v[2]); 
+}
 
 string CDicomReaderData::getAttribute(const DcmTagKey &tagKey, bool required, const char *default_value)
 {
@@ -424,13 +547,13 @@ string CDicomReaderData::getAttribute(const string& key, bool required, const ch
 void CDicomReaderData::add_attribute(CAttributedData& image, const char *key, ETagRequirement  required, const char *default_value)
 {
 	string value = getAttribute(key, required == tr_yes);
-	if (!value.empty())
+	if (!value.empty()) {
 		image.set_attribute(key, value);
+	}
 	else if (required == tr_yes_defaulted) 
 		image.set_attribute(key, string(default_value));
 }
 
-
 template <typename I>
 void CDicomReaderData::getPixelData_LittleEndianExplicitTransfer(I out_begin, size_t size)
 {
@@ -438,18 +561,17 @@ void CDicomReaderData::getPixelData_LittleEndianExplicitTransfer(I out_begin, si
 	if (status.bad()) {
 		throw create_exception<runtime_error>( "DICOM: error loading pixel data:", status.text());
 	}
-
 	const Uint16 *values;
 	long unsigned int count;
 	OFCondition cnd = dcm.getDataset()->findAndGetUint16Array(DCM_PixelData, values, &count, false);
 	if (cnd.good()) {
 		if (size != count) {
 			throw create_exception<runtime_error>( "bogus file, expect ", size, " pixels, ", 
-						     "but got data for ", count, " pixels");
+							       "but got data for ", count, " pixels");
 		}
 		copy(values, values+count, out_begin);
 	}else {
-		throw create_exception<runtime_error>( "DICOM: required value PixelData:", status.text());
+		throw create_exception<runtime_error>( "DICOM: required value PixelData:", cnd.text());
 	}
 }
 
@@ -470,12 +592,43 @@ void CDicomReaderData::getPixelData(I out_begin, size_t size)
 	getPixelData_LittleEndianExplicitTransfer(out_begin, size);
 }
 
+C2DFVector CDicomReaderData::getImagePixelSpacing()
+{
+	OFString help;
+	OFCondition success = dcm.getDataset()->findAndGetOFString(DCM_ImagerPixelSpacing, help, 0);
+	if (success.bad()) {
+		throw create_exception<runtime_error>( "Neither 'PixelSpacing' nor 'ImagerPixelSpacing' found!"
+						       " As a workaround to can add either of them by using 'dcmodify'");
+	}
+	C2DFVector result;
+
+	istringstream swidth(help.data());
+	swidth >> result.x;
+
+	success = dcm.getDataset()->findAndGetOFString(DCM_ImagerPixelSpacing, help, 1);
+	if (success.bad()) {
+		throw create_exception<runtime_error>( "Second value in 'ImagerPixelSpacing' not found!"
+						       " As a workaround to can add either of them by using 'dcmodify'");
+	}
+	istringstream sheight(help.data());
+	sheight >> result.y;
+
+	cvinfo() << "The image contained no 'PixelSpacing' tag, only 'ImagerPixelSpacing' that corresponds to the " 
+		 << "detector pixel spacing. If you can not assume that the rays are parallel, then your object "
+		 << "pixel spacing might have to be scaled."; 
+
+	// indicate that this is not physical pixel size but imager pixel size 
+	result.x = -result.x; 
+	return result;
+	
+}
+
 C2DFVector CDicomReaderData::getPixelSize()
 {
 	OFString help;
 	OFCondition success = dcm.getDataset()->findAndGetOFString(DCM_PixelSpacing, help, 0);
 	if (success.bad()) {
-		throw create_exception<runtime_error>( "Required attribute 'PixelSpacing' not found");
+		return getImagePixelSpacing(); 
 	}
 	C2DFVector result;
 
@@ -501,7 +654,9 @@ private:
 	void setValueString(const string& key, const string& value);
 	void setValueString(const DcmTagKey& key, const string& value, bool meta);
 	void setSize(const C2DBounds& size);
-	void setPixelSpacing(const C2DFVector& value);
+	void setPixelSpacing(const DcmTagKey& key, const C2DFVector& value);
+	void setAcquisitionTime(double time_seconds); 
+	void setFloatArrayAsString(const DcmTagKey& key, const vector<double>& values); 
 	void setValueStringIfKeyExists(const CAttributeMap::value_type& value);
 	friend struct CDicomImageSaver;
 };
@@ -526,6 +681,7 @@ template <typename T>
 struct pixel_trait {
 	enum { AllocSize = 8 * sizeof(T)};
 	enum { UseSize = 8 * sizeof(T)};
+	enum { PixelRepn = 0};
 	enum { supported = 0 };
 	static void copy_pixel_data(DcmDataset& /*dataset*/, const T2DImage<T>& /*image*/) {
 		assert(!"There is no code here");
@@ -536,12 +692,27 @@ template <>
 struct pixel_trait<unsigned short> {
 	enum { AllocSize = 16};
 	enum { UseSize = 16};
+	enum { PixelRepn = 0};
 	enum { supported = 1};
 	static void copy_pixel_data(DcmDataset& dataset, const C2DUSImage& image) {
 		dataset.putAndInsertUint16Array(DCM_PixelData, (const Uint16*)&image(0,0), image.size());
 	}
 };
 
+template <>
+struct pixel_trait<signed short> {
+	enum { AllocSize = 16};
+	enum { UseSize = 16};
+	enum { PixelRepn = 1};
+	enum { supported = 1};
+	static void copy_pixel_data(DcmDataset& dataset, const C2DSSImage& image) {
+		OFCondition cnd = dataset.putAndInsertUint16Array(DCM_PixelData, (const Uint16*)&image(0,0), image.size());
+		if (!cnd.good()) {
+			throw create_exception<runtime_error>( "DICOM: unable to set signed short array to PixelData:", cnd.text());
+		}
+	}
+};
+
 template <typename T>
 CDicomImageSaver::result_type CDicomImageSaver::operator ()(const T2DImage<T>& image)const
 {
@@ -550,7 +721,9 @@ CDicomImageSaver::result_type CDicomImageSaver::operator ()(const T2DImage<T>& i
 
 	parent->setValueUint16(DCM_BitsAllocated, pixel_trait<T>::AllocSize);
 	parent->setValueUint16(DCM_BitsStored, pixel_trait<T>::UseSize);
-
+	parent->setValueUint16(DCM_HighBit, pixel_trait<T>::UseSize - 1);
+	parent->setValueUint16(DCM_PixelRepresentation, pixel_trait<T>::PixelRepn);
+	
 	auto  minmax = minmax_element(image.begin(), image.end());
 
 
@@ -561,14 +734,81 @@ CDicomImageSaver::result_type CDicomImageSaver::operator ()(const T2DImage<T>& i
 	return true;
 }
 
+void CDicomWriterData::setFloatArrayAsString(const DcmTagKey& key, const vector<double>& values)
+{
+	
+	if (values.empty()) {
+		cvwarn() << "Try to set " << key << " from empty array\n"; 
+		return; 
+	}
+
+	ostringstream value_str; 
+	value_str << setprecision(8)<< values[0]; 
+	for (unsigned i = 1; i < values.size(); ++i) 
+		value_str << '\\' << setprecision(8)<< values[i];
+	
+	setValueString(key, value_str.str(), false); 
+}
+
 CDicomWriterData::CDicomWriterData(const C2DImage& image)
 {
 	setValueUint16(DCM_SamplesPerPixel, 1);
 	setSize(image.get_size());
-	setPixelSpacing(image.get_pixel_size());
+	
+	setPixelSpacing(image.has_attribute(IDAttrPixelSizeIsImager) ? 
+			DCM_ImagerPixelSpacing : DCM_PixelSpacing, 
+			image.get_pixel_size());
+	
+	// special treatment for the acquistion time
+	if (image.has_attribute(IDAcquisitionTime)) {
+		const double time = image.get_attribute_as<double>(IDAcquisitionTime); 
+		cvdebug() << "CDicomWriterData: save" << IDAcquisitionTime << ": " << setw(10) << setprecision(20) << time << "s\n"; 
+		setAcquisitionTime(time); 
+	}
 
-	for(auto i = image.begin_attributes(); i != image.end_attributes(); ++i)
+	for(auto i = image.begin_attributes(); i != image.end_attributes(); ++i) {
 		setValueStringIfKeyExists(*i);
+	}
+
+	auto rot = C3DDMatrix::_1; 
+	// set position and orientation 
+	auto prot_attr = image.get_attribute("rotation3d"); 
+	if (prot_attr) {
+		auto prot_attr_pointer = dynamic_cast<const C3DRotationAttribute*>(prot_attr.get()); 
+		if (prot_attr_pointer) {
+			C3DRotation rot_attr = *prot_attr_pointer; 
+			rot = rot_attr.as_matrix_3x3();
+		}else{
+			cvwarn() << "image has a 'rotation3d' attribute, but not of type C3DRotationAttribute, ignoring\n"; 
+		}
+	}else{
+		cvdebug()  << "image has no 'rotation3d' attribute, default to unity matrix\n"; 
+	}
+	
+	const vector<double> ovalues{rot.x.x, rot.x.y, rot.x.z, rot.y.x, rot.y.y, rot.y.z}; 
+	setFloatArrayAsString(DCM_ImageOrientationPatient, ovalues); 
+	
+	C3DFVector pos = C3DFVector::_0; 
+
+	auto porigin_attr = image.get_attribute("origin3d");
+	if (porigin_attr) {
+		auto porigin_attr_pointer = dynamic_cast<const CVoxelAttribute*>(porigin_attr.get()); 
+		if (porigin_attr_pointer) {
+			pos = *porigin_attr_pointer; 
+		} else {
+			cvwarn() << "image has a 'origin3d' attribute of value '"
+				 << porigin_attr->as_string() 
+				 <<"', not of type CVoxelAttribute ("
+				 << typeid(CVoxelAttribute).name() << ") but "
+				 << typeid(*porigin_attr).name() 
+				 <<" , ignoring\n"; 
+		}
+	}else {
+		cvdebug()  << "image has no 'origin3d' attribute, default to (0,0,0)\n"; 
+	}
+	
+	const vector<double>  pvalues{pos.x, pos.y, pos.z}; 
+	setFloatArrayAsString(DCM_ImagePositionPatient, pvalues); 
 
 	if (!image.has_attribute(IDMediaStorageSOPClassUID))
 		setValueString(IDMediaStorageSOPClassUID, "1.2.840.10008.5.1.4.1.1.4");
@@ -606,13 +846,33 @@ void CDicomWriterData::setSize(const C2DBounds& size)
 	setValueUint16(DCM_Columns, size.x);
 }
 
-void CDicomWriterData::setPixelSpacing(const C2DFVector& value)
+void CDicomWriterData::setPixelSpacing(const DcmTagKey& key, const C2DFVector& value)
 {
 	stringstream pixelspacing;
 	pixelspacing << value.x << "\\" << value.y;
-	setValueString(DCM_PixelSpacing, pixelspacing.str(), false);
+	setValueString(key, pixelspacing.str(), false);
 }
 
+void CDicomWriterData::setAcquisitionTime(double time_seconds)
+{
+	
+	OFTime of_time; 
+	of_time.setTimeInSeconds(time_seconds); 
+
+	DcmTime *dcm_time = new DcmTime(DCM_AcquisitionTime); 	
+	
+	OFString dicomTime; 
+	OFCondition status = DcmTime::getDicomTimeFromOFTime(of_time, dicomTime, OFTrue, OFTrue); 
+	if (!status.good() ) {
+		cvwarn() << "CDicomWriter: error setting acquisition time: " << status.text() << "\n"; 
+		return ;
+	}
+	// well, that is stupid, but DcmTime doesn't support to set the fraction flag in SetOFTime
+	dcm_time->putString (dicomTime.c_str()); 
+	dcm.getDataset()->insert(dcm_time, OFTrue); 
+}
+
+
 void CDicomWriterData::setValueStringIfKeyExists(const CAttributeMap::value_type& value)
 {
 	if (LookupMap::instance().has_key(value.first))
@@ -684,14 +944,4 @@ CDicomReader EXPORT_DICOM ugly_trick_writer_dcm_to_reader_dcm(CDicomWriter& writ
 	return CDicomReader(new CDicomReaderData(writer.impl->dcm));
 }
 
-EXPORT_DICOM const char * IDMediaStorageSOPClassUID= "MediaStorageSOPClassUID";
-EXPORT_DICOM const char * IDStudyDescription = "StudyDescription";
-EXPORT_DICOM const char * IDSamplesPerPixel = "IDSamplesPerPixel";
-EXPORT_DICOM const char * IDSeriesDescription = "SeriesDescription";
-
-EXPORT_DICOM const char * IDTestValue = "TestValue";
-EXPORT_DICOM const char * IDTransferSyntaxUID = "TransferSyntaxUID";
-EXPORT_DICOM const char * IDSOPClassUID = "SOPClassUID";
-
-
 NS_MIA_END
