@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,15 +56,6 @@ EXPORT_2D C2DFImage operator * (const C2DImageSolverAmultx& A, const C2DFImage&
 	return result; 
 }
 
-
-using boost::filesystem::path; 
-using std::list; 
-C2DImageSparseSolverTestPath::C2DImageSparseSolverTestPath() 
-{
-	CPathNameArray sksearchpath({path(MIA_BUILD_ROOT"/mia/2d/sparsimgsolver")});
-	C2DImageSparseSolverPluginHandler::set_search_path(sksearchpath); 
-}
-
 template <> const char *  const 
 TPluginHandler<TFactory<C2DImageSolverAmultx>>::m_help =  "These plug-ins define the multiplication of a sparse matrix "
 				"with a vector that is used in the sparse image solver class.";
