@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,6 +66,14 @@ T3DDatafield<T>::T3DDatafield(const C3DBounds& size, const T *data):
 {
 	std::copy(data, data + m_data->size(), m_data->begin()); 
 }
+
+template <typename T>
+T3DDatafield<T>::T3DDatafield(const C3DBounds& size, const data_array& data):
+	m_size(size), 
+	m_xy(size.x * size.y), 
+	m_data(new data_array(data))
+{
+}
 	
 template <typename T>
 T3DDatafield<T>::~T3DDatafield()
