@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 
 #include <cmath>
 #include <fstream>
-#include <mia/internal/autotest.hh>
 
 #include <mia/core/spacial_kernel.hh>
 #include <mia/3d/interpolator.hh>
@@ -34,8 +33,6 @@ using namespace ::boost;
 using namespace boost::unit_test;
 namespace bfs=boost::filesystem;
 
-CSplineKernelTestPath splinekernel_init_path; 
-
 struct ipfFixture {
 	ipfFixture():
 		ipf("bspline:d=3", "mirror")
@@ -1100,29 +1097,6 @@ struct TransformSplineFixtureMixed: public TransformSplineFixtureFieldBase2 {
 	double graddiv2(double x, double y, double z)const;
 };
 
-BOOST_FIXTURE_TEST_CASE( test_mix_bspline4_10_4, TransformSplineFixtureMixed )
-{
-	init(10, 4);
-
-
-	const double testdiv = 7.0 * pow(M_PI, 1.5) / sqrt(2.0); 
-	const double testcurl = testdiv / 4.0; 
-
-	double divval = transform->get_divcurl_cost(1.0, 0.0);
-	BOOST_CHECK_CLOSE( divval, testdiv, 0.1); 	
-
-	
-	double graddivcurl = transform->get_divcurl_cost(1.0, 1.0);
-	BOOST_CHECK_CLOSE( graddivcurl, testdiv + testcurl, 0.1); 	
-	
-
-	double gradcurl = transform->get_divcurl_cost(0.0, 1.0);
-	BOOST_CHECK_CLOSE( gradcurl, testcurl, 0.1); 	
-
-	cvinfo() << "divval  / testdiv= " << divval  / testdiv << "\n"; 
-	cvinfo() << "gradcurl / testcurl = " << gradcurl / testcurl << "\n"; 
-}
-
 double TransformSplineFixtureMixed::fx(double x, double y, double z)const 
 {
 	return x * exp(-x*x-y*y-z*z);
