@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ void TIOPluginHandler<I>::do_initialise()
 		i->second->add_suffixes(m_suffixmap);
 	
 	m_compress_sfx.insert(".Z"); 
+	m_compress_sfx.insert(".xz"); 
 	m_compress_sfx.insert(".gz"); 
 	m_compress_sfx.insert(".bz2"); 
 }
@@ -76,7 +77,7 @@ TIOPluginHandler<I>::preferred_plugin_ptr(const std::string& fname) const
 	CSuffixmap::const_iterator p = m_suffixmap.find(fsuffix);
 	if (p != m_suffixmap.end())
 		return this->plugin(p->second.c_str());
-	return 0; 
+	return nullptr; 
 }
 
 template <class I> 
@@ -273,7 +274,7 @@ TIOPluginHandler<I>::CDatapoolPlugin::CDatapoolPlugin():
 }
 
 template <class I> 
-std::string TIOPluginHandler<I>::CDatapoolPlugin::do_get_preferred_suffix() const
+const std::string TIOPluginHandler<I>::CDatapoolPlugin::do_get_preferred_suffix() const
 {
 	return "@"; 
 }
@@ -306,7 +307,12 @@ const std::string TIOPluginHandler<I>::CDatapoolPlugin::do_get_descr() const
 	return "Virtual IO to and from the internal data pool"; 
 }
 
-
+template <class I>
+bool TIOPluginHandler<I>::do_validate_parameter_string(const std::string& s) const
+{
+	auto p = preferred_plugin_ptr(s); 
+	return p != nullptr ? true : false;  
+}
 
 NS_MIA_END
 
