@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -176,7 +176,7 @@ const char *g_plugin_root = nullptr;
 
 PrepareTestPluginPath::PrepareTestPluginPath()
 {
-	g_plugin_root = PLUGIN_TEST_ROOT "/" PLUGIN_INSTALL_PATH; 
+	g_plugin_root = MIA_BUILD_ROOT "/plugintest/" PLUGIN_INSTALL_PATH; 
 }
 
 PrepareTestPluginPath::~PrepareTestPluginPath()
@@ -185,6 +185,7 @@ PrepareTestPluginPath::~PrepareTestPluginPath()
 }
 
 #ifdef WIN32
+
 EXPORT_CORE const string get_plugin_root()
 {
 	static string result;
@@ -223,10 +224,9 @@ EXPORT_CORE const string get_plugin_root()
 	}
 	return result;
 }
+
 #else
 
-
-
 const string EXPORT_CORE get_plugin_root()
 {
 	// this is the override for tests
@@ -239,6 +239,7 @@ const string EXPORT_CORE get_plugin_root()
 		return string(plugin_root); 
 	return string(PLUGIN_SEARCH_PATH);
 }
+
 #endif
 
 NS_MIA_END
