@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,6 +64,7 @@ struct CSlopeStatisticsImpl {
 	int get_index() const; 
 	std::pair<size_t, float>  get_gradient_peak(int start_movement) const; 
 	float get_level_change(size_t center) const; 
+	int get_max_frequency_slot() const; 
 private:
 
 	void evaluate_curve_length() const;
@@ -87,6 +88,8 @@ private:
 	mutable int m_start_movement;
 	mutable bool m_gradient_peak_valid;
 	mutable bool m_wt_valid;
+	mutable int m_max_freq_slot; 
+
 
 	mutable pair<size_t, float>  m_first_peak;
 	mutable pair<size_t, float>  m_gradient_peak;
@@ -272,10 +275,23 @@ float CSlopeStatisticsImpl::get_positive_time_mean() const
 }
 
 
+int CSlopeStatistics::get_max_frequency_slot() const
+{
+	assert(impl); 
+	return impl->get_max_frequency_slot(); 
+}
 
+int CSlopeStatisticsImpl::get_max_frequency_slot() const
+{
+	if (!m_mean_freq_valid)
+		evaluate_frequency(); 
+	return m_max_freq_slot; 
+}
 
 void CSlopeStatisticsImpl::evaluate_frequency() const
 {
+	float max_slot_energy = 0.0; 
+	m_max_freq_slot = 0; 
 	m_mean_freq = 0.0;
 	m_energy = 0.0;
 	CFFT1D_R2C fft(m_series.size());
@@ -287,6 +303,10 @@ void CSlopeStatisticsImpl::evaluate_frequency() const
 		float snorm = sqrt(n);
 		m_mean_freq += k * snorm;
 		m_energy += snorm;
+		if (max_slot_energy < snorm) {
+			max_slot_energy = snorm; 
+			m_max_freq_slot = k; 
+		}
 	}
 	m_mean_freq /= m_energy;
 	m_mean_freq_valid = true;
@@ -472,7 +492,12 @@ float CSlopeStatistics::get_level_change(size_t center) const
 
 float CSlopeStatisticsImpl::get_level_change(size_t center) const
 {
-	assert(center < m_series.size() - 1 && center > 0);
+	if (center >= m_series.size() - 1) {
+		return -(accumulate(m_series.begin(), m_series.begin(), 0.0f) / m_series.size()); 
+	}
+	if  (center <= 0) {
+		return (accumulate(m_series.begin(), m_series.begin(), 0.0f) / m_series.size()); 
+	}
 	
 	float before = accumulate(m_series.begin(), m_series.begin() + center, 0.0f) / center; 
 	float after = accumulate(m_series.begin() + center + 1, m_series.end(), 0.0f) / (m_series.size() - center - 1);
