@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -147,11 +147,12 @@ int do_main(int argc, char **argv)
 
 	const auto& imageio = C3DImageIOPluginHandler::instance();
 
-	options.add(make_opt( src1_filename, "first", '1', "first input image ", CCmdOption::required, &imageio));
-	options.add(make_opt( src2_filename, "second", '2', "second input image ", CCmdOption::required, &imageio));
-	options.add(make_opt( out_filename, "out-file", 'o', "output vector field", CCmdOption::required, &imageio));
+	options.add(make_opt( src1_filename, "first", '1', "first input image ", CCmdOptionFlags::required_input, &imageio));
+	options.add(make_opt( src2_filename, "second", '2', "second input image ", CCmdOptionFlags::required_input, &imageio));
+	options.add(make_opt( out_filename, "out-file", 'o', "linearly interpolated image", 
+			      CCmdOptionFlags::required_output, &imageio));
 	options.add(make_opt( positions, "positions", 'p', 
-				    "image series positions (first, target, second)", CCmdOption::required));
+				    "image series positions (first, target, second)", CCmdOptionFlags::required));
 	options.add(make_opt( self_test, "self-test", 0, "run a self test of the tool"));
 
 	if (options.parse(argc, (const char **)argv) != CCmdOptionList::hr_no)
